Method: ReportBuilder.json_report_path

Defined in:
lib/report_builder.rb

.json_report_pathString

Returns Report Builder json report output file path with file name without extension

Returns:

  • (String)

    json_report_path json report output file path with file name without extension



282
283
284
# File 'lib/report_builder.rb', line 282

def self.json_report_path
  options[:json_report_path] || options[:report_path]
end